@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,11 +29,9 @@ $filterForm = (new CFilter('web.toptriggers.filter.state'))
 $severity_columns = [0 => [], 1 => []];
 
 foreach (range(TRIGGER_SEVERITY_NOT_CLASSIFIED, TRIGGER_SEVERITY_COUNT - 1) as $severity) {
-	$severity_columns[$severity % 2][] = new CLabel([
-		(new CCheckBox('severities['.$severity.']'))
-			->setChecked(in_array($severity, $this->data['filter']['severities'])),
-		getSeverityName($severity, $this->data['config'])
-	], 'severities['.$severity.']');
+	$severity_columns[$severity % 2][] = (new CCheckBox('severities['.$severity.']'))
+		->setLabel(getSeverityName($severity, $this->data['config']))
+		->setChecked(in_array($severity, $this->data['filter']['severities']));
 }
 
 $filterColumn1 = (new CFormList())
