@@ -434,8 +434,12 @@ else {
 		'preservekeys' => true
 	]);
 
-	$user_type = CWebUser::getType();
-	if ($user_type != USER_TYPE_SUPER_ADMIN) {
+	order_result($data['maps'], $sortField, $sortOrder);
+
+	// paging
+	$data['paging'] = getPagingLine($data['maps'], $sortOrder, new CUrl('sysmaps.php'));
+
+	if (CWebUser::getType() != USER_TYPE_SUPER_ADMIN) {
 		$editable_maps = API::Map()->get([
 			'output' => [],
 			'sysmapids' => array_keys($data['maps']),
@@ -449,11 +453,6 @@ else {
 		unset($map);
 	}
 
-	order_result($data['maps'], $sortField, $sortOrder);
-
-	// paging
-	$data['paging'] = getPagingLine($data['maps'], $sortOrder, new CUrl('sysmaps.php'));
-
 	// render view
 	$mapView = new CView('monitoring.sysmap.list', $data);
 	$mapView->render();
